package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.ContainerServicesMapper;
import com.zyc.system.domain.ContainerServices;
import com.zyc.system.service.IContainerServicesService;

/**
 * 容器服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class ContainerServicesServiceImpl implements IContainerServicesService 
{
    @Autowired
    private ContainerServicesMapper containerServicesMapper;

    /**
     * 查询容器服务
     * 
     * @param id 容器服务主键
     * @return 容器服务
     */
    @Override
    public ContainerServices selectContainerServicesById(Integer id)
    {
        return containerServicesMapper.selectContainerServicesById(id);
    }

    /**
     * 查询容器服务列表
     * 
     * @param containerServices 容器服务
     * @return 容器服务
     */
    @Override
    public List<ContainerServices> selectContainerServicesList(ContainerServices containerServices)
    {
        return containerServicesMapper.selectContainerServicesList(containerServices);
    }

    /**
     * 新增容器服务
     * 
     * @param containerServices 容器服务
     * @return 结果
     */
    @Override
    public int insertContainerServices(ContainerServices containerServices)
    {
        return containerServicesMapper.insertContainerServices(containerServices);
    }

    /**
     * 修改容器服务
     * 
     * @param containerServices 容器服务
     * @return 结果
     */
    @Override
    public int updateContainerServices(ContainerServices containerServices)
    {
        return containerServicesMapper.updateContainerServices(containerServices);
    }

    /**
     * 批量删除容器服务
     * 
     * @param ids 需要删除的容器服务主键
     * @return 结果
     */
    @Override
    public int deleteContainerServicesByIds(Integer[] ids)
    {
        return containerServicesMapper.deleteContainerServicesByIds(ids);
    }

    /**
     * 删除容器服务信息
     * 
     * @param id 容器服务主键
     * @return 结果
     */
    @Override
    public int deleteContainerServicesById(Integer id)
    {
        return containerServicesMapper.deleteContainerServicesById(id);
    }
}
